@@ -11,6 +11,7 @@
 #include <vector>
 
 #include "common/Mutex.h"
+#include "common/RWLock.h"
 #include "common/snap_types.h"
 #include "include/buffer.h"
 #include "include/rbd/librbd.hpp"
@@ -42,6 +43,7 @@ namespace librbd {
     bool snap_exists; // false if our snap_id was deleted
     // whether the image was opened read-only. cannot be changed after opening
     bool read_only;
+    bool flush_encountered;
 
     std::map<rados::cls::lock::locker_id_t,
 	     rados::cls::lock::locker_info_t> lockers;
@@ -59,12 +61,12 @@ namespace librbd {
      * Lock ordering:
      * md_lock, cache_lock, snap_lock, parent_lock, refresh_lock
      */
-    Mutex md_lock; // protects access to the mutable image metadata that
+    RWLock md_lock; // protects access to the mutable image metadata that
                    // isn't guarded by other locks below
                    // (size, features, image locks, etc)
     Mutex cache_lock; // used as client_lock for the ObjectCacher
-    Mutex snap_lock; // protects snapshot-related member variables:
-    Mutex parent_lock; // protects parent_md and parent
+    RWLock snap_lock; // protects snapshot-related member variables:
+    RWLock parent_lock; // protects parent_md and parent
     Mutex refresh_lock; // protects refresh_seq and last_refresh
 
     bool old_format;
@@ -102,8 +104,8 @@ namespace librbd {
     librados::snap_t get_snap_id(std::string in_snap_name) const;
     int get_snap_name(snapid_t snap_id, std::string *out_snap_name) const;
     int get_parent_spec(snapid_t snap_id, parent_spec *pspec);
-    int get_snap_size(std::string in_snap_name, uint64_t *out_size) const;
     int is_snap_protected(string in_snap_name, bool *is_protected) const;
+    int is_snap_unprotected(string in_snap_name, bool *is_unprotected) const;
 
     uint64_t get_current_size() const;
     uint64_t get_object_size() const;
@@ -126,11 +128,15 @@ namespace librbd {
 			   uint64_t *overlap) const;
     void aio_read_from_cache(object_t o, bufferlist *bl, size_t len,
 			     uint64_t off, Context *onfinish);
-    void write_to_cache(object_t o, bufferlist& bl, size_t len, uint64_t off);
+    void write_to_cache(object_t o, bufferlist& bl, size_t len, uint64_t off,
+			Context *onfinish);
     int read_from_cache(object_t o, bufferlist *bl, size_t len, uint64_t off);
+    void user_flushed();
+    void flush_cache_aio(Context *onfinish);
     int flush_cache();
     void shutdown_cache();
     void invalidate_cache();
+    void clear_nonexistence_cache();
     int register_watch();
     void unregister_watch();
     size_t parent_io_len(uint64_t offset, size_t length,
