@@ -172,7 +172,7 @@ static void log_usage(struct req_state *s, const string& op_name)
   string user;
 
   if (s->bucket_name)
-    user = s->bucket_owner;
+    user = s->bucket_owner.get_id();
   else
     user = s->user.user_id;
 
@@ -306,7 +306,8 @@ int rgw_log_op(RGWRados *store, struct req_state *s, const string& op_name, OpsL
   entry.user = s->user.user_id;
   if (s->object_acl)
     entry.object_owner = s->object_acl->get_owner().get_id();
-  entry.bucket_owner = s->bucket_owner;
+  entry.bucket_owner = s->bucket_owner.get_id();
+
 
   uint64_t bytes_sent = s->cio->get_bytes_sent();
   uint64_t bytes_received = s->cio->get_bytes_received();
@@ -339,13 +340,13 @@ int rgw_log_op(RGWRados *store, struct req_state *s, const string& op_name, OpsL
 
   if (s->cct->_conf->rgw_ops_log_rados) {
     string oid = render_log_object_name(s->cct->_conf->rgw_log_object_name, &bdt,
-				        s->bucket.bucket_id, entry.bucket.c_str());
+				        s->bucket.bucket_id, entry.bucket);
 
-    rgw_obj obj(store->params.log_pool, oid);
+    rgw_obj obj(store->zone.log_pool, oid);
 
     ret = store->append_async(obj, bl.length(), bl);
     if (ret == -ENOENT) {
-      ret = store->create_pool(store->params.log_pool);
+      ret = store->create_pool(store->zone.log_pool);
       if (ret < 0)
         goto done;
       // retry
@@ -365,7 +366,7 @@ done:
 
 int rgw_log_intent(RGWRados *store, rgw_obj& obj, RGWIntentEvent intent, const utime_t& timestamp, bool utc)
 {
-  rgw_bucket intent_log_bucket(store->params.intent_log_pool);
+  rgw_bucket intent_log_bucket(store->zone.intent_log_pool);
 
   rgw_intent_log_entry entry;
   entry.obj = obj;
